@@ -23,7 +23,7 @@ Usage::
     list_jobs_paginator: ListJobsPaginator = client.get_paginator("list_jobs")
     list_revision_assets_paginator: ListRevisionAssetsPaginator = client.get_paginator("list_revision_assets")
 """
-from mypy_boto3_dataexchange.client import DataExchangeClient as Client, DataExchangeClient
+from mypy_boto3_dataexchange.client import DataExchangeClient, DataExchangeClient as Client
 from mypy_boto3_dataexchange.paginator import (
     ListDataSetRevisionsPaginator,
     ListDataSetsPaginator,
